@@ -17,6 +17,18 @@ This is useful to immediately get notified when failures happen,
 and also for general monitoring / reporting.
 """
 
-from zenml.alerter.base_alerter import BaseAlerter
+from zenml.alerter.base_alerter import (
+    BaseAlerter,
+    BaseAlerterConfig,
+    BaseAlerterFlavor,
+)
+from zenml.steps.step_interfaces.base_alerter_step import (
+    BaseAlerterStepParameters,
+)
 
-__all__ = ["BaseAlerter"]
+__all__ = [
+    "BaseAlerter",
+    "BaseAlerterConfig",
+    "BaseAlerterFlavor",
+    "BaseAlerterStepParameters",
+]
