@@ -26,6 +26,7 @@ order to find out which version of ZenML you are running, type:
 ```bash
    zenml version
 ```
+
 If you ever need more information on exactly what a certain command will
 do, use the ``--help`` flag attached to the end of your command string.
 
@@ -35,22 +36,23 @@ while using the ``zenml`` command, type:
 ```bash
    zenml --help
 ```
+
 If you were instead looking to know more about a specific command, you
 can type something like this:
 
 ```bash
-   zenml metadata-store register --help
+   zenml artifact-store register --help
 ```
 
-This will give you information about how to register a metadata store.
+This will give you information about how to register an artifact store.
 (See below for more on that).
 
 If you want to instead understand what the concept behind a group is, you 
 can use the `explain` sub-command. For example, to see more details behind 
-what a `metadata-store` is, you can type:
+what a `artifact-store` is, you can type:
 
 ```bash
-zenml metadata-store explain
+zenml artifact-store explain
 ```
 
 This will give you an explanation of that concept in more detail.
@@ -59,7 +61,7 @@ Beginning a Project
 -------------------
 
 In order to start working on your project, initialize a ZenML repository
-within your current directory with ZenML’s own config and resource management
+within your current directory with ZenML's own config and resource management
 tools:
 
 ```bash
@@ -72,38 +74,28 @@ provides!
 By default, ``zenml init`` will install its own hidden ``.zen`` folder
 inside the current directory from which you are running the command.
 You can also pass in a directory path manually using the
-``--repo_path`` option:
+``--path`` option:
 
 ```bash
-zenml init --repo_path /path/to/dir
-```
-If you wish to specify that you do not want analytics to be transmitted
-back to ZenML about your usage of the tool, pass in ``False`` to the
-``--analytics_opt_in`` option:
+zenml init --path /path/to/dir
 
-```bash
-zenml init --analytics_opt_in false
-```
 If you wish to delete all data relating to your project from the
 directory, use the ``zenml clean`` command. This will:
 
--  delete all pipelines
+-  delete all pipelines and pipeline runs
 -  delete all artifacts
 -  delete all metadata
 
-*Note that the* ``clean`` *command is not implemented for the current
-version.*
-
 Loading and using pre-built examples
 ------------------------------------
 
-If you don’t have a project of your own that you’re currently working
+If you don't have a project of your own that you're currently working
 on, or if you just want to play around a bit and see some functional
-code, we’ve got your back! You can use the ZenML CLI tool to download
+code, we've got your back! You can use the ZenML CLI tool to download
 some pre-built examples.
 
 We know that working examples are a great way to get to know a tool, so
-we’ve made some examples for you to use to get started. (This is
+we've made some examples for you to use to get started. (This is
 something that will grow as we add more).
 
 To list all the examples available to you, type:
@@ -121,19 +113,21 @@ zenml example info quickstart
 If you want to pull all the examples into your current working directory
 (wherever you are executing the ``zenml`` command from in your
 terminal), the CLI will create a ``zenml_examples`` folder for you if it
-doesn’t already exist whenever you use the ``pull`` subcommand. The
+doesn't already exist whenever you use the ``pull`` subcommand. The
 default is to copy all the examples, like this:
 
 ```bash
 zenml example pull
 ```
-If you’d only like to pull a single example, add the name of that
+
+If you'd only like to pull a single example, add the name of that
 example (for example, ``quickstart``) as an argument to the same
 command, as follows:
 
 ```bash
 zenml example pull quickstart
 ```
+
 If you would like to force-redownload the examples, use the ``--yes``
 or ``-y`` flag as in this example:
 
@@ -148,6 +142,7 @@ download examples corresponding to a previous release of ZenML, use the
 ```bash
 zenml example pull --yes --version 0.3.8
 ```
+
 If you wish to run the example, allowing the ZenML CLI to do the work of setting
 up whatever dependencies are required, use the ``run`` subcommand:
 
@@ -193,31 +188,6 @@ Uninstalling a specific integration is as simple as typing:
 zenml integration uninstall INTEGRATION_NAME
 ```
 
-Customizing your Metadata Store
--------------------------------
-
-The configuration of each pipeline, step, backend, and produced
-artifacts are all tracked within the metadata store. By default, ZenML
-initializes your repository with a metadata store kept on your local
-machine. If you wish to register a new metadata store, do so with the
-``register`` command:
-
-```bash
-zenml metadata-store register METADATA_STORE_NAME --flavor=METADATA_STORE_FLAVOR [--OPTIONS]
-```
-If you wish to list the metadata stores that have already been
-registered within your ZenML project / repository, type:
-
-```bash
-zenml metadata-store list
-```
-If you wish to delete a particular metadata store, pass the name of the
-metadata store into the CLI with the following command:
-
-```bash
-zenml metadata-store delete METADATA_STORE_NAME
-```
-
 Customizing your Artifact Store
 -------------------------------
 
@@ -229,12 +199,16 @@ to register a new artifact store, do so with the ``register`` command:
 ```bash
 zenml artifact-store register ARTIFACT_STORE_NAME --flavor=ARTIFACT_STORE_FLAVOR [--OPTIONS]
 ```
+
 If you wish to list the artifact stores that have already been
 registered within your ZenML project / repository, type:
 
 ```bash
 zenml artifact-store list
 ```
+
+If you wish to update/share
+
 If you wish to delete a particular artifact store, pass the name of the
 artifact store into the CLI with the following command:
 
@@ -256,12 +230,14 @@ command:
 ```bash
 zenml orchestrator register ORCHESTRATOR_NAME --flavor=ORCHESTRATOR_FLAVOR [--ORCHESTRATOR_OPTIONS]
 ```
+
 If you wish to list the orchestrators that have already been registered
 within your ZenML project / repository, type:
 
 ```bash
 zenml orchestrator list
 ```
+
 If you wish to delete a particular orchestrator, pass the name of the
 orchestrator into the CLI with the following command:
 
@@ -419,14 +395,14 @@ To register a secret, use the `register` command and pass the key-value pairs
 as command line arguments:
 
 ```bash
-zenml secret register SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
+zenml secrets-manager secret register SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
 ```
 
 Note that the keys and values will be preserved in your `bash_history` file, so
 you may prefer to use the interactive `register` command instead:
 
 ```shell
-zenml secret register SECRET_NAME -i
+zenml secrets-manager secret register SECRET_NAME -i
 ```
 
 As an alternative to the interactive mode, also useful for values that
@@ -434,7 +410,7 @@ are long or contain newline or special characters, you can also use the special
 `@` syntax to indicate to ZenML that the value needs to be read from a file:
 
 ```bash
-zenml secret register SECRET_NAME --schema=aws \
+zenml secrets-manager secret register SECRET_NAME --schema=aws \
    --aws_access_key_id=1234567890 \
    --aws_secret_access_key=abcdefghij \
    --aws_session_token=@/path/to/token.txt
@@ -444,32 +420,32 @@ zenml secret register SECRET_NAME --schema=aws \
 To list all the secrets available, use the `list` command:
 
 ```bash
-zenml secret list
+zenml secrets-manager secret list
 ```
 
 To get the key-value pairs for a particular secret, use the `get` command:
 
 ```bash
-zenml secret get SECRET_NAME
+zenml secrets-manager secret get SECRET_NAME
 ```
 
 To update a secret, use the `update` command:
 
 ```bash
-zenml secret update SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
+zenml secrets-manager secret update SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
 ```
 
 Note that the keys and values will be preserved in your `bash_history` file, so
 you may prefer to use the interactive `update` command instead:
 
 ```shell
-zenml secret update SECRET_NAME -i
+zenml secrets-manager secret update SECRET_NAME -i
 ```
 
 Finally, to delete a secret, use the `delete` command:
 
 ```bash
-zenml secret delete SECRET_NAME
+zenml secrets-manager secret delete SECRET_NAME
 ```
 
 Add a Feature Store to your Stack
@@ -486,6 +462,48 @@ zenml feature-store register FEATURE_STORE_NAME --flavor=feast
 Once you have registered your feature store as a stack component, you can use it
 in your ZenML Stack.
 
+Interacting with Model Deployers
+-----------------------------------------
+
+Model deployers are stack components responsible for online model serving.
+They are responsible for deploying models to a remote server. Model deployers
+also act as a registry for models that are served with ZenML.
+
+If you wish to register a new model deployer, do so with the
+`register` command:
+
+```bash
+zenml model-deployer register MODEL_DEPLOYER_NAME --flavor=MODEL_DEPLOYER_FLAVOR [--OPTIONS]
+```
+
+If you wish to list the model-deployers that have already been registered
+within your ZenML project / repository, type:
+
+```bash
+zenml model-deployer list
+```
+
+If you wish to get more detailed information about a particular model deployer
+within your ZenML project / repository, type:
+
+```bash
+zenml model-deployer describe MODEL_DEPLOYER_NAME
+```
+
+If you wish to delete a particular model deployer, pass the name of the
+model deployers into the CLI with the following command:
+
+```bash
+zenml model-deployer delete MODEL_DEPLOYER_NAME
+```
+
+If you wish to retrieve logs corresponding to a particular model deployer, pass
+the name of the model deployer into the CLI with the following command:
+
+```bash
+zenml model-deployer logs MODEL_DEPLOYER_NAME
+```
+
 Interacting with Deployed Models
 --------------------------------
 
@@ -493,7 +511,7 @@ If you want to simply see what models have been deployed within your stack, run
 the following command:
 
 ```bash
-zenml served-models list
+zenml model-deployer models list
 ```
 
 This should give you a list of served models containing their uuid, the name
@@ -505,38 +523,38 @@ If you want further information about a specific model, simply copy the
 UUID and the following command.
 
 ```bash
-zenml served-models describe <UUID>
+zenml model-deployer models describe <UUID>
 ```
 
 If you are only interested in the prediction-url of the specific model you can
 also run:
 
 ```bash
-zenml served-models get-url <UUID>
+zenml model-deployer models get-url <UUID>
 ```
 
 Finally, you will also be able to start/stop the services using the following
  two commands:
 
 ```bash
-zenml served-models start <UUID>
-zenml served-models stop <UUID>
+zenml model-deployer models start <UUID>
+zenml model-deployer models stop <UUID>
 ```
 
 If you want to completely remove a served model you can also irreversibly delete
  it using:
 
 ```bash
-zenml served-models delete <UUID>
+zenml model-deployer models delete <UUID>
 ```
 
 Administering the Stack
 -----------------------
 
-The stack is a grouping of your artifact store, your metadata store and
-your orchestrator. With the ZenML tool, switching from a local stack to
-a distributed cloud environment can be accomplished with just a few CLI
-commands.
+The stack is a grouping of your artifact store, your orchestrator, and other
+optional MLOps tools like experiment trackers or model deployers.
+With the ZenML tool, switching from a local stack to a distributed cloud
+environment can be accomplished with just a few CLI commands.
 
 To register a new stack, you must already have registered the individual
 components of the stack using the commands listed above.
@@ -546,21 +564,34 @@ takes four arguments as in the following example:
 
 ```bash
 zenml stack register STACK_NAME \
-       -m METADATA_STORE_NAME \
        -a ARTIFACT_STORE_NAME \
        -o ORCHESTRATOR_NAME
 ```
 
-Each corresponding argument should be the name you passed in as an
-identifier for the artifact store, metadata store or orchestrator when
-you originally registered it. (If you want to use your secrets manager, you
-should pass its name in with the `-x` option flag.)
+Each corresponding argument should be the name, id or even the first few letters
+ of the id that uniquely identify the artifact store or orchestrator.
+(If you want to use your secrets manager, you should pass its name in with the
+`-x` option flag.)
 
 If you want to immediately set this newly created stack as your active stack,
 simply pass along the `--set` flag.
 
 ```bash
-zenml stack register STACK_NAME -m METADATA_STORE_NAME ... --set
+zenml stack register STACK_NAME ... --set
+```
+
+If you want to share the stack and all of its components with everyone using
+the same ZenML deployment, simply pass along the `--share` flag.
+
+```bash
+zenml stack register STACK_NAME ... --share
+```
+
+Even if you haven't done so at creation time of the stack, you can always
+decide to do so at a later stage.
+
+```bash
+zenml stack share STACK_NAME
 ```
 
 To list the stacks that you have registered within your current ZenML
@@ -593,13 +624,6 @@ If you want to copy a stack, run the following command:
 ```shell
 zenml stack copy SOURCE_STACK_NAME TARGET_STACK_NAME
 ```
-You can optionally specify profiles from which the stack should be copied 
-to and from:
-```shell
-zenml stack copy SOURCE_STACK_NAME TARGET_STACK_NAME \
-   [--from SOURCE_PROFILE_NAME] \
-   [--to TARGET_PROFILE_NAME]
-```
 
 If you wish to transfer one of your stacks to another machine, you can do so 
 by exporting the stack configuration and then importing it again.
@@ -614,7 +638,7 @@ This will create a FILENAME.yaml containing the config of your stack and all
 of its components, which you can then import again like this:
 
 ```bash
-zenml stack import STACK_NAME FILENAME.yaml
+zenml stack import STACK_NAME -f FILENAME.yaml
 ```
 
 If you wish to update a stack that you have already registered, first make sure
@@ -653,17 +677,10 @@ If you want to copy a stack component, run the following command:
 ```bash
 zenml STACK_COMPONENT copy SOURCE_COMPONENT_NAME TARGET_COMPONENT_NAME
 ```
-You can optionally specify profiles from which the component should be copied 
-to and from:
-```bash
-zenml STACK_COMPONENT copy SOURCE_COMPONENT_NAME TARGET_COMPONENT_NAME \
-   [--from SOURCE_PROFILE_NAME] \
-   [--to TARGET_PROFILE_NAME]
-```
 
 If you wish to update a specific stack component, use the following command,
 switching out "STACK_COMPONENT" for the component you wish to update (i.e.
-'orchestrator' or 'artifact-store' etc):
+'orchestrator' or 'artifact-store' etc.):
 
 ```shell
 zenml STACK_COMPONENT update --some_property=NEW_VALUE
@@ -680,11 +697,282 @@ If you wish to remove an attribute (or multiple attributes) from a stack
 component, use the following command:
 
 ```shell
-zenml STACK_COMPONENT remove-attribute STACK_COMPONENT_NAME --ATTRIBUTE_NAME [--OTHER_ATTRIBUTE_NAME]
+zenml STACK_COMPONENT remove-attribute STACK_COMPONENT_NAME ATTRIBUTE_NAME [OTHER_ATTRIBUTE_NAME]
 ```
 
 Note that you can only remove optional attributes.
 
+If you want to register secrets for all secret references in a stack, use the
+following command:
+
+```shell
+zenml stack register-secrets [<STACK_NAME>]
+```
+
+Administering your Pipelines
+----------------------------
+
+ZenML provides several CLI commands to help you administer your pipelines and
+pipeline runs.
+
+After you have run some pipelines by by executing the corresponding Python 
+scripts, you can list all pipelines via:
+
+```bash
+zenml pipeline list
+```
+
+Since every pipeline run creates a new pipeline by default, you might
+occasionally want to delete a pipeline, which you can do via:
+
+```bash
+zenml pipeline delete PIPELINE_NAME
+```
+
+This will delete the pipeline and change all corresponding pipeline runs to
+become unlisted (not linked to any pipeline).
+
+To list all pipeline runs that you have executed, use:
+
+```bash
+zenml pipeline runs list
+```
+
+These are currently read-only and cannot be modified or deleted.
+
+If you would like to switch to a different ZenML deployment 
+(e.g., when switching from a local deployment to a cloud deployment), you can
+migrate your existing pipeline runs by exporting them to a YAML file via:
+
+```bash
+zenml pipeline runs export FILENAME.yaml
+```
+
+This will create a FILENAME.yaml containing all your pipeline runs, which, after
+connecting to the new ZenML deployment, you can then import again like this:
+
+```bash
+zenml pipeline runs import FILENAME.yaml
+```
+
+Managing the local ZenML Dashboard
+----------------------------------
+
+The ZenML dashboard is a web-based UI that allows you to visualize and navigate
+the stack configurations, pipelines and pipeline runs tracked by ZenML among
+other things. You can start the ZenML dashboard locally by running the following
+command:
+
+```bash
+zenml up
+```
+
+This will start the dashboard on your local machine where you can access it at
+the URL printed to the console. If you want to stop the dashboard, simply run:
+
+```bash
+zenml down
+```
+
+The `zenml up` command has a few additional options that you can use to
+customize how the ZenML dashboard is running.
+
+By default, the dashboard is started as a background process. On some operating
+systems, this capability is not available. In this case, you can use the
+`--blocking` flag to start the dashboard in the foreground:
+
+```bash
+zenml up --blocking
+```
+
+This will block the terminal until you stop the dashboard with CTRL-C.
+
+Another option you can use, if you have Docker installed on your machine, is to
+run the dashboard in a Docker container. This is useful if you don't want to
+install all the Zenml server dependencies on your machine. To do so, simply run:
+
+```bash
+zenml up --docker
+```
+
+The TCP port and the host address that the dashboard uses to listen for
+connections can also be customized. Using an IP address that is not the default
+`localhost` or 127.0.0.1 is especially useful if you're running some type of
+local ZenML orchestrator, such as the k3d Kubeflow orchestrator or Docker
+orchestrator, that cannot directly connect to the local ZenML server.
+
+For example, to start the dashboard on port 9000 and have it listen
+on all locally available interfaces on your machine, run:
+
+```bash
+zenml up --port 9000 --ip-address 0.0.0.0
+```
+
+Note that the above 0.0.0.0 IP address also exposes your ZenML dashboard
+externally through your public interface. Alternatively, you can choose an
+explicit IP address that is configured on one of your local interfaces, such as
+the Docker bridge interface, which usually has the IP address `172.17.0.1`:
+
+```bash
+zenml up --port 9000 --ip-address 172.17.0.1
+```
+
+Managing the global configuration
+---------------------------------
+
+The ZenML global configuration CLI commands cover options such as enabling or
+disabling the collection of anonymous usage statistics, changing the logging
+verbosity and configuring your ZenML client to connect to a remote database or
+ZenML server.
+
+In order to help us better understand how the community uses ZenML, the library
+reports anonymized usage statistics. You can always opt-out by using the CLI
+command:
+
+```bash
+zenml analytics opt-out
+```
+
+If you want to opt back in, use the following command:
+
+```bash
+zenml analytics opt-in
+```
+
+The verbosity of the ZenML client output can be configured using the
+``zenml logging`` command. For example, to set the verbosity to DEBUG, run:
+
+```bash
+zenml logging set-verbosity DEBUG
+```
+
+The ZenML client can be configured to connect to a remote database or ZenML
+server with the `zenml connect` command. If no arguments are supplied, ZenML
+will attempt to connect to the last ZenML server deployed from the local host
+using the 'zenml deploy' command:
+
+```bash
+zenml connect
+```
+
+To connect to a ZenML server, you can either pass the configuration as command
+line arguments or as a YAML file:
+
+```bash
+zenml connect --url=https://zenml.example.com:8080 --username=admin --no-verify-ssl
+```
+
+or
+
+```bash
+zenml connect --config=/path/to/zenml_server_config.yaml
+```
+
+The YAML file should have the following structure when connecting to a ZenML
+server:
+
+```yaml
+url: <The URL of the ZenML server>
+username: <The username to use for authentication>
+password: <The password to use for authentication>
+verify_ssl: |
+   <Either a boolean, in which case it controls whether the
+   server's TLS certificate is verified, or a string, in which case it
+   must be a path to a CA certificate bundle to use or the CA bundle
+   value itself>
+```
+
+Example of a ZenML server YAML configuration file:
+
+```yaml
+url: https://ac8ef63af203226194a7725ee71d85a-7635928635.us-east-1.elb.amazonaws.com/zenml
+username: admin
+password: Pa$$word123
+verify_ssl: |
+-----BEGIN CERTIFICATE-----
+MIIDETCCAfmgAwIBAgIQYUmQg2LR/pHAMZb/vQwwXjANBgkqhkiG9w0BAQsFADAT
+MREwDwYDVQQDEwh6ZW5tbC1jYTAeFw0yMjA5MjYxMzI3NDhaFw0yMzA5MjYxMzI3
+...
+ULnzA0JkRWRnFqH6uXeJo1KAVqtxn1xf8PYxx3NlNDr9wi8KKwARf2lwm6sH4mvq
+1aZ/0iYnGKCu7rLJzxeguliMf69E
+-----END CERTIFICATE-----
+```
+
+Both options can be combined, in which case the command line arguments will
+override the values in the YAML file. For example, it is possible and
+recommended that you supply the password only as a command line argument:
+
+```bash
+zenml connect --username zenml --password=Pa@#$#word --config=/path/to/zenml_server_config.yaml
+```
+
+To disconnect from the current ZenML server and revert to using the local
+default database, use the following command:
+
+```bash
+zenml disconnect
+```
+
+You can inspect the current ZenML configuration at any given time using the
+following command:
+
+```bash
+zenml status
+```
+
+Example output:
+
+```
+ zenml status
+Running without an active repository root.
+Connected to a ZenML server: 'https://ac8ef63af203226194a7725ee71d85a-7635928635.us-east-1.elb.amazonaws.com'
+The current user is: 'default'
+The active project is: 'default' (global)
+The active stack is: 'default' (global)
+The status of the local dashboard:
+              ZenML server 'local'              
+┏━━━━━━━━━━━━━━━━┯━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
+┃ URL            │ http://172.17.0.1:9000      ┃
+┠────────────────┼─────────────────────────────┨
+┃ STATUS         │ ✅                          ┃
+┠────────────────┼─────────────────────────────┨
+┃ STATUS_MESSAGE │ Docker container is running ┃
+┠────────────────┼─────────────────────────────┨
+┃ CONNECTED      │                             ┃
+┗━━━━━━━━━━━━━━━━┷━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛
+```
+
+The ``zenml connect`` command can also be used to configure your client with
+more advanced options, such as connecting directly to a local or remote SQL
+database. In this case, the `--raw-config` flag must be passed to instruct the
+CLI to not validate or fill in the missing configuration fields. For example,
+to connect to a remote MySQL database, run:
+
+```bash
+zenml connect --raw-config --config=/path/to/mysql_config.yaml
+```
+
+with a YAML configuration file that looks like this:
+
+```yaml
+type: sql
+url: mysql://<username>:<password>@mysql.database.com/<database_name>
+ssl_ca: |
+   -----BEGIN CERTIFICATE-----
+   MIIEBjCCAu6gAwIBAgIJAMc0ZzaSUK51MA0GCSqGSIb3DQEBCwUAMIGPMQswCQYD
+   VQQGEwJVUzEQMA4GA1UEBwwHU2VhdHRsZTETMBEGA1UECAwKV2FzaGluZ3RvbjEi
+   MCAGA1UECgwZQW1hem9uIFdlYiBTZXJ2aWNlcywgSW5jLjETMBEGA1UECwwKQW1h
+   ...
+   KoZIzj0EAwMDaAAwZQIxAIqqZWCSrIkZ7zsv/FygtAusW6yvlL935YAWYPVXU30m
+   jkMFLM+/RJ9GMvnO8jHfCgIwB+whlkcItzE9CRQ6CsMo/d5cEHDUu/QW6jSIh9BR
+   OGh9pTYPVkUbBiKPA7lVVhre
+   -----END CERTIFICATE-----
+
+ssl_cert: null
+ssl_key: null
+ssl_verify_server_cert: false
+```
+
 Managing users, teams, projects and roles
 -----------------------------------------
 
@@ -700,6 +988,12 @@ or
 zenml user delete USER_NAME
 ```
 
+A freshly created user will by default be assigned the admin role. This
+behavior can be overwritten:
+```bash
+zenml user create USER_NAME --role guest
+```
+
 To see a list of all users, run:
 ```bash
 zenml user list
@@ -730,10 +1024,16 @@ To see a list of all teams, run:
 zenml team list
 ```
 
-A role groups permissions and can be assigned to users or teams. To create or
-delete a role, run one of the following commands:
+A role groups permissions to resources. Currently, there are the following
+globally scoped roles to choose from: 'write', 'read' and 'me'. To create
+a role, run one of the following commands:
+```bash
+zenml role create ROLE_NAME -p write -p read -p me
+zenml role create ROLE_NAME -p read
+```
+
+To delete a role run:
 ```bash
-zenml role create ROLE_NAME
 zenml role delete ROLE_NAME
 ```
 
@@ -742,6 +1042,11 @@ To see a list of all roles, run:
 zenml role list
 ```
 
+You can also update the role name and the attached permissions of a role:
+```bash
+zenml role update [-n <NEW_NAME>| -r <PERMISSION_TO_REMOVE>| -a <PERMISSION_TO_ADD>]
+```
+
 If you want to assign or revoke a role from users or teams, you can run
 
 ```bash
@@ -760,60 +1065,115 @@ You can see a list of all current role assignments by running:
 zenml role assignment list
 ```
 
-Interacting with Model Deployers
------------------------------------------
-
-Model deployers are stack components responsible for online model serving.
-They are responsible for deploying models to a remote server. Model deployers
-also act as a registry for models that are served with ZenML. 
-
-If you wish to register a new model deployer, do so with the
-`register` command:
-
+At any point you may inspect all available permissions:
 ```bash
-zenml model-deployer register MODEL_DEPLOYER_NAME --flavor=MODEL_DEPLOYER_FLAVOR [--OPTIONS]
+zenml permission list
 ```
 
-If you wish to list the model-deployers that have already been registered
-within your ZenML project / repository, type:
+Deploying ZenML to the cloud
+----------------------------
+
+The ZenML CLI provides a simple way to deploy ZenML to the cloud.
+
+Deploying cloud resources using Stack Recipes
+-----------------------------------------------
+
+Stack Recipes allow you to quickly deploy fully-fledged MLOps stacks with just
+a few commands. Each recipe uses Terraform modules under the hood and once
+executed can set up a ZenML stack, ready to run your pipelines!
+
+A number of stack recipes are already available at [the `mlops-stacks` repository](https://github.com/zenml-io/mlops-stacks/). List them
+using the following command:
 
 ```bash
-zenml model-deployer list
+zenml stack recipes list
 ```
 
-If you wish to get more detailed information about a particular model deployer
-within your ZenML project / repository, type:
+If you want to pull any specific recipe to your local system, use the `pull`
+command:
 
 ```bash
-zenml model-deployer describe MODEL_DEPLOYER_NAME
+zenml stack recipe pull <stack-recipe-name>
 ```
 
-If you wish to delete a particular model deployer, pass the name of the
-model deployers into the CLI with the following command:
+If you don't specify a name, `zenml stack recipe pull` will pull all the
+recipes.
+
+If you notice any inconsistency with the locally-pulled version and the GitHub
+repository, run the `pull` command with the `-y` flag to download any recent
+changes.
 
 ```bash
-zenml model-deployer delete MODEL_DEPLOYER_NAME
+zenml stack recipe pull <stack-recipe-name> -y
 ```
 
-If you wish to retrieve logs corresponding to a particular model deployer, pass the name
-of the model deployer into the CLI with the following command:
+Optionally, you can specify the relative path at which you want to install the
+stack recipe(s). Use the `-p` or `--path` flag.
+```bash
+zenml stack recipe pull <stack-recipe-name> --path=<PATH>
+```
+By default, all recipes get downloaded under a directory called
+`zenml_stack_recipes`.
+
+To deploy a recipe, use the `deploy` command. Before running deploy, review the 
+`zenml_stack_recipes/<stack-recipe-name>/locals.tf` file for configuring
+non-sensitive variables and the
+`zenml_stack_recipes/<stack-recipe-name>/values.tfvars`
+file to add sensitive information like access keys and passwords.
 
 ```bash
-zenml model-deployer logs MODEL_DEPLOYER_NAME
+zenml stack recipe deploy <stack-recipe-name>
 ```
 
+Running deploy without any options will create a new ZenML stack with the same
+name as the stack recipe name. Use the `--stack-name` option to specify your
+own name.
+
+```bash
+zenml stack recipe deploy <stack-recipe-name> --stack-name=my_stack
+```
+
+If you wish to review the stack information from the newly-generated resources
+before importing, you can run `deploy` with the `--no-import` flag.
+
+```bash
+zenml stack recipe deploy <stack-recipe-name> --no-import
+```
+This will still create a stack YAML configuration file but will not auto-import
+it. You can make any changes you want to the configuration and then run
+`zenml stack import` manually.
+
+To remove all resources created as part of the recipe, run the `destroy`
+command.
+
+```bash
+zenml stack recipe destroy <stack-recipe-name>
+```
+
+To delete all the recipe files from your system, you can use the `clean`
+ command.
+
+```bash
+zenml stack recipe clean
+```
+
+This deletes all the recipes from the default path where they were downloaded.
 """
 
+from zenml.cli.annotator import *  # noqa
 from zenml.cli.base import *  # noqa
 from zenml.cli.config import *  # noqa
 from zenml.cli.example import *  # noqa
 from zenml.cli.feature import *  # noqa
 from zenml.cli.integration import *  # noqa
+from zenml.cli.model import *  # noqa
 from zenml.cli.pipeline import *  # noqa
+from zenml.cli.project import *  # noqa
+from zenml.cli.role import *  # noqa
 from zenml.cli.secret import *  # noqa
-from zenml.cli.served_models import *  # noqa
 from zenml.cli.server import *  # noqa
 from zenml.cli.stack import *  # noqa
 from zenml.cli.stack_components import *  # noqa
+from zenml.cli.stack_recipes import *  # noqa
 from zenml.cli.user_management import *  # noqa
 from zenml.cli.version import *  # noqa
