@@ -18,10 +18,9 @@ import shutil
 import subprocess
 import sys
 from pathlib import Path
-from typing import List, Optional, cast
+from typing import List, Optional
 
 import click
-from packaging.version import Version, parse
 from rich.markdown import Markdown
 from rich.text import Text
 
@@ -34,7 +33,7 @@ from zenml.exceptions import GitNotFoundError
 from zenml.io import fileio
 from zenml.logger import get_logger
 from zenml.utils import io_utils
-from zenml.utils.analytics_utils import AnalyticsEvent, track_event
+from zenml.utils.analytics_utils import AnalyticsEvent, event_handler
 
 logger = get_logger(__name__)
 
@@ -176,7 +175,7 @@ class LocalExample:
         Args:
             example_runner: Sequence of locations of executable file(s)
                             to run the example
-            force: Whether to force the install
+            force: Whether to force the installation
             prevent_stack_setup: Prevents the example from setting up a custom
                 stack.
 
@@ -185,43 +184,46 @@ class LocalExample:
             FileNotFoundError: If the example runner script is not found.
             subprocess.CalledProcessError: If the example runner script fails.
         """
-        if all(map(fileio.exists, example_runner)):
-            call = (
-                example_runner
-                + ["--executable", self.executable_python_example]
-                + ["-y"] * force
-                + ["--no-stack-setup"] * prevent_stack_setup
-            )
-            try:
-                # TODO [ENG-271]: Catch errors that might be thrown
-                #  in subprocess
-                subprocess.check_call(
-                    call,
-                    cwd=str(self.path),
-                    shell=click._compat.WIN,
-                    env=os.environ.copy(),
+        with event_handler(
+            event=AnalyticsEvent.RUN_EXAMPLE,
+            metadata={"example_name": self.name},
+        ):
+
+            if all(map(fileio.exists, example_runner)):
+                call = (
+                    example_runner
+                    + ["--executable", self.executable_python_example]
+                    + ["-y"] * force
+                    + ["--no-stack-setup"] * prevent_stack_setup
                 )
-            except RuntimeError:
-                raise NotImplementedError(
-                    f"Currently the example {self.name} "
-                    "has no implementation for the "
-                    "run method"
-                )
-            except subprocess.CalledProcessError as e:
-                if e.returncode == 38:
+                try:
+                    # TODO [ENG-271]: Catch errors that might be thrown
+                    #  in subprocess
+                    subprocess.check_call(
+                        call,
+                        cwd=str(self.path),
+                        shell=click._compat.WIN,
+                        env=os.environ.copy(),
+                    )
+                except RuntimeError:
                     raise NotImplementedError(
                         f"Currently the example {self.name} "
                         "has no implementation for the "
                         "run method"
                     )
-                raise
-        else:
-            raise FileNotFoundError(
-                "Bash File(s) to run Examples not found at" f"{example_runner}"
-            )
-
-        # Telemetry
-        track_event(AnalyticsEvent.RUN_EXAMPLE, {"example_name": self.name})
+                except subprocess.CalledProcessError as e:
+                    if e.returncode == 38:
+                        raise NotImplementedError(
+                            f"Currently the example {self.name} "
+                            "has no implementation for the "
+                            "run method"
+                        )
+                    raise
+            else:
+                raise FileNotFoundError(
+                    "Bash File(s) to run Examples not found at"
+                    f"{example_runner}"
+                )
 
 
 class Example:
@@ -297,7 +299,7 @@ class ExamplesRepo:
 
         try:
             self.repo = Repo(self.cloning_path)
-        except NoSuchPathError or InvalidGitRepositoryError:
+        except (NoSuchPathError, InvalidGitRepositoryError):
             self.repo = None  # type: ignore
             logger.debug(
                 f"`Cloning_path`: {self.cloning_path} was empty, "
@@ -317,12 +319,11 @@ class ExamplesRepo:
             The active version of the examples repository.
         """
         for branch in self.repo.heads:
-            branch_name = cast(str, branch.name)
             if (
-                branch_name.startswith("release/")
+                branch.name.startswith("release/")
                 and branch.commit == self.repo.head.commit
             ):
-                return branch_name[len("release/") :]
+                return branch.name[len("release/") :]
 
         return None
 
@@ -333,9 +334,11 @@ class ExamplesRepo:
         Returns:
             The name of the latest release branch.
         """
+        from packaging.version import Version, parse
+
         tags = sorted(
             self.repo.tags,
-            key=lambda t: t.commit.committed_datetime,  # type: ignore
+            key=lambda t: t.commit.committed_datetime,
         )
         latest_tag = parse(tags[-1].name)
         if type(latest_tag) is not Version:
@@ -390,6 +393,14 @@ class ExamplesRepo:
             self.delete()
             logger.error("Canceled download of repository.. Rolled back.")
 
+    def pull(self) -> None:
+        """Pull or clone the latest repository version."""
+        if not self.cloning_path.exists():
+            self.clone()
+        else:
+            logger.info("Fetching latest examples repository")
+            self.repo.git.pull()
+
     def delete(self) -> None:
         """Delete `cloning_path` if it exists.
 
@@ -451,10 +462,10 @@ class GitExamplesHandler(object):
 
     @property
     def is_matching_versions(self) -> bool:
-        """Whether the checked out examples are on the same code version as ZenML.
+        """Checks whether examples are on the same code version as ZenML.
 
         Returns:
-            Whether the checked out examples are on the same code version as ZenML.
+            Checks whether examples are on the same code version as ZenML.
         """
         return zenml_version_installed == str(self.examples_repo.active_version)
 
@@ -517,11 +528,9 @@ class GitExamplesHandler(object):
         """
         from git.exc import GitCommandError
 
-        if not self.examples_repo.is_cloned:
-            self.examples_repo.clone()
-        elif force:
+        if self.examples_repo.is_cloned and force:
             self.examples_repo.delete()
-            self.examples_repo.clone()
+        self.examples_repo.pull()
 
         try:
             self.examples_repo.checkout(branch=branch)
@@ -536,20 +545,22 @@ class GitExamplesHandler(object):
         """Pulls the latest examples from the examples repository."""
         self.pull(branch=self.examples_repo.latest_release_branch, force=True)
 
-    def copy_example(self, example: Example, destination_dir: str) -> None:
+    @staticmethod
+    def copy_example(example_: Example, destination_dir: str) -> None:
         """Copies an example to the destination_dir.
 
         Args:
-            example: The example to copy.
+            example_: The example to copy.
             destination_dir: The destination directory to copy the example to.
         """
         io_utils.create_dir_if_not_exists(destination_dir)
         io_utils.copy_dir(
-            str(example.path_in_repo), destination_dir, overwrite=True
+            str(example_.path_in_repo), destination_dir, overwrite=True
         )
 
-    def clean_current_examples(self) -> None:
-        """Deletes the ZenML examples directory from your current working directory."""
+    @staticmethod
+    def clean_current_examples() -> None:
+        """Deletes the examples directory from the current working directory."""
         examples_directory = os.path.join(os.getcwd(), "zenml_examples")
         shutil.rmtree(examples_directory)
 
@@ -602,8 +613,8 @@ def list_examples(git_examples_handler: GitExamplesHandler) -> None:
     """
     check_for_version_mismatch(git_examples_handler)
     examples = [
-        {"example_name": example.name}
-        for example in git_examples_handler.get_examples()
+        {"example_name": example_.name}
+        for example_ in git_examples_handler.get_examples()
     ]
     print_table(examples)
 
@@ -769,29 +780,30 @@ def pull(
         error(str(e))
 
     else:
-        for example in examples:
-            destination_dir = os.path.join(os.getcwd(), path, example.name)
-            if LocalExample(
-                name=example.name, path=Path(destination_dir)
-            ).is_present():
-                if force or confirmation(
-                    f"Example {example.name} is already pulled. "
-                    "Do you wish to overwrite the directory at "
-                    f"{destination_dir}?"
-                ):
-                    fileio.rmtree(destination_dir)
-                else:
-                    warning(f"Example {example.name} not overwritten.")
-                    continue
+        for example_ in examples:
+            with event_handler(
+                event=AnalyticsEvent.PULL_EXAMPLE,
+                metadata={"example_name": example_.name},
+            ):
+                destination_dir = os.path.join(os.getcwd(), path, example_.name)
+                if LocalExample(
+                    name=example_.name, path=Path(destination_dir)
+                ).is_present():
+                    if force or confirmation(
+                        f"Example {example_.name} is already pulled. "
+                        "Do you wish to overwrite the directory at "
+                        f"{destination_dir}?"
+                    ):
+                        fileio.rmtree(destination_dir)
+                    else:
+                        warning(f"Example {example_.name} not overwritten.")
+                        continue
 
-            declare(f"Pulling example {example.name}...")
+                declare(f"Pulling example {example_.name}...")
 
-            io_utils.create_dir_if_not_exists(destination_dir)
-            git_examples_handler.copy_example(example, destination_dir)
-            declare(f"Example pulled in directory: {destination_dir}")
-            track_event(
-                AnalyticsEvent.PULL_EXAMPLE, {"example_name": example.name}
-            )
+                io_utils.create_dir_if_not_exists(destination_dir)
+                git_examples_handler.copy_example(example_, destination_dir)
+                declare(f"Example pulled in directory: {destination_dir}")
 
 
 @example.command(
