@@ -22,8 +22,11 @@ a Pydantic configuration object that is used to store and retrieve
 configuration. This ``GlobalConfiguration`` object handles the serialization and
 deserialization of the configuration options that are stored in the file in
 order to persist the configuration across sessions.
-
-The ``ProfileConfiguration`` class is used to model the configuration of a
-Profile. A ``GlobalConfiguration`` object can contain multiple
-``ProfileConfiguration`` instances.
 """
+from zenml.config.docker_settings import DockerSettings
+from zenml.config.resource_settings import ResourceSettings
+
+__all__ = [
+    "DockerSettings",
+    "ResourceSettings",
+]
