@@ -13,16 +13,21 @@
 #  permissions and limitations under the License.
 """Implementation of a default container registry class."""
 
-from typing import ClassVar
 
 from zenml.container_registries.base_container_registry import (
-    BaseContainerRegistry,
+    BaseContainerRegistryFlavor,
 )
 from zenml.enums import ContainerRegistryFlavor
 
 
-class DefaultContainerRegistry(BaseContainerRegistry):
+class DefaultContainerRegistryFlavor(BaseContainerRegistryFlavor):
     """Class for default ZenML container registries."""
 
-    # Class Configuration
-    FLAVOR: ClassVar[str] = ContainerRegistryFlavor.DEFAULT.value
+    @property
+    def name(self) -> str:
+        """Name of the flavor.
+
+        Returns:
+            The name of the flavor.
+        """
+        return ContainerRegistryFlavor.DEFAULT.value
