@@ -14,19 +14,30 @@
 """The base class for feature stores."""
 
 from abc import ABC, abstractmethod
-from typing import Any, ClassVar, Dict, List, Union
+from typing import Any, Dict, List, Type, Union, cast
 
 import pandas as pd
 
 from zenml.enums import StackComponentType
-from zenml.stack import StackComponent
+from zenml.stack import Flavor, StackComponent
+from zenml.stack.stack_component import StackComponentConfig
+
+
+class BaseFeatureStoreConfig(StackComponentConfig):
+    """Base config for feature stores."""
 
 
 class BaseFeatureStore(StackComponent, ABC):
     """Base class for all ZenML feature stores."""
 
-    TYPE: ClassVar[StackComponentType] = StackComponentType.FEATURE_STORE
-    FLAVOR: ClassVar[str]
+    @property
+    def config(self) -> BaseFeatureStoreConfig:
+        """Returns the `BaseFeatureStoreConfig` config.
+
+        Returns:
+            The configuration.
+        """
+        return cast(BaseFeatureStoreConfig, self._config)
 
     @abstractmethod
     def get_historical_features(
@@ -63,3 +74,35 @@ class BaseFeatureStore(StackComponent, ABC):
         Returns:
             The latest online feature data as a dictionary.
         """
+
+
+class BaseFeatureStoreFlavor(Flavor):
+    """Base class for all ZenML feature store flavors."""
+
+    @property
+    def type(self) -> StackComponentType:
+        """Returns the flavor type.
+
+        Returns:
+            The flavor type.
+        """
+        return StackComponentType.FEATURE_STORE
+
+    @property
+    def config_class(self) -> Type[BaseFeatureStoreConfig]:
+        """Config class for this flavor.
+
+        Returns:
+            The config class.
+        """
+        return BaseFeatureStoreConfig
+
+    @property
+    @abstractmethod
+    def implementation_class(self) -> Type[BaseFeatureStore]:
+        """Implementation class.
+
+        Returns:
+            The implementation class.
+        """
+        return BaseFeatureStore
