@@ -19,15 +19,14 @@ and an `io` module to handle file operations on Azure Blob Storage.
 The Azure Step Operator integration submodule provides a way to run ZenML steps
 in AzureML.
 """
-from typing import List
+from typing import List, Type
 
-from zenml.enums import StackComponentType
 from zenml.integrations.constants import AZURE
 from zenml.integrations.integration import Integration
-from zenml.zen_stores.models import FlavorWrapper
+from zenml.stack import Flavor
 
 AZURE_ARTIFACT_STORE_FLAVOR = "azure"
-AZURE_SECRETS_MANAGER_FLAVOR = "azure_key_vault"
+AZURE_SECRETS_MANAGER_FLAVOR = "azure"
 AZUREML_STEP_OPERATOR_FLAVOR = "azureml"
 
 
@@ -39,39 +38,27 @@ class AzureIntegration(Integration):
         "adlfs==2021.10.0",
         "azure-keyvault-keys",
         "azure-keyvault-secrets",
-        "azure-identity",
-        "azureml-core==1.39.0.post1",
+        "azure-identity==1.10.0",
+        "azureml-core==1.48.0",
     ]
 
     @classmethod
-    def flavors(cls) -> List[FlavorWrapper]:
+    def flavors(cls) -> List[Type[Flavor]]:
         """Declares the flavors for the integration.
 
         Returns:
             List of stack component flavors for this integration.
         """
+        from zenml.integrations.azure.flavors import (
+            AzureArtifactStoreFlavor,
+            AzureMLStepOperatorFlavor,
+            AzureSecretsManagerFlavor,
+        )
+
         return [
-            FlavorWrapper(
-                name=AZURE_ARTIFACT_STORE_FLAVOR,
-                source="zenml.integrations.azure.artifact_stores"
-                ".AzureArtifactStore",
-                type=StackComponentType.ARTIFACT_STORE,
-                integration=cls.NAME,
-            ),
-            FlavorWrapper(
-                name=AZURE_SECRETS_MANAGER_FLAVOR,
-                source="zenml.integrations.azure.secrets_managers"
-                ".AzureSecretsManager",
-                type=StackComponentType.SECRETS_MANAGER,
-                integration=cls.NAME,
-            ),
-            FlavorWrapper(
-                name=AZUREML_STEP_OPERATOR_FLAVOR,
-                source="zenml.integrations.azure.step_operators"
-                ".AzureMLStepOperator",
-                type=StackComponentType.STEP_OPERATOR,
-                integration=cls.NAME,
-            ),
+            AzureArtifactStoreFlavor,
+            AzureSecretsManagerFlavor,
+            AzureMLStepOperatorFlavor,
         ]
 
 
