@@ -17,19 +17,26 @@ AIRFLOW = "airflow"
 AWS = "aws"
 AZURE = "azure"
 AZUREML = "azureml"
+BENTOML = "bentoml"
 DASH = "dash"
+DEEPCHECKS = "deepchecks"
 EVIDENTLY = "evidently"
 FACETS = "facets"
 FEAST = "feast"
 GCP = "gcp"
-GCP_SECRETS_MANAGER = "gcp_secrets_manager"
 GITHUB = "github"
 GRAPHVIZ = "graphviz"
+KSERVE = "kserve"
+HUGGINGFACE = "huggingface"
 GREAT_EXPECTATIONS = "great_expectations"
 KUBEFLOW = "kubeflow"
+LABEL_STUDIO = "label_studio"
 KUBERNETES = "kubernetes"
 LIGHTGBM = "lightgbm"
 MLFLOW = "mlflow"
+NEPTUNE = "neptune"
+NEURAL_PROPHET = "neural_prophet"
+PILLOW = "pillow"
 PLOTLY = "plotly"
 PYTORCH = "pytorch"
 PYTORCH_L = "pytorch_lightning"
@@ -39,12 +46,13 @@ SCIPY = "scipy"
 SELDON = "seldon"
 SKLEARN = "sklearn"
 SLACK = "slack"
+SPARK = "spark"
+TEKTON = "tekton"
+TENSORBOARD = "tensorboard"
 TENSORFLOW = "tensorflow"
 VAULT = "vault"
 WHYLOGS = "whylogs"
 WANDB = "wandb"
 VERTEX = "vertex"
-NEURAL_PROPHET = "neural_prophet"
-HUGGINGFACE = "huggingface"
 XGBOOST = "xgboost"
 VAULT = "vault"
