@@ -22,15 +22,40 @@ dashboard (visualized as an html file or in your Jupyter notebook), or as a JSON
 file.
 """
 
+from typing import List, Type
+
+from zenml.enums import StackComponentType
 from zenml.integrations.constants import EVIDENTLY
 from zenml.integrations.integration import Integration
+from zenml.stack import Flavor
+
+EVIDENTLY_DATA_VALIDATOR_FLAVOR = "evidently"
 
 
 class EvidentlyIntegration(Integration):
     """[Evidently](https://github.com/evidentlyai/evidently) integration for ZenML."""
 
     NAME = EVIDENTLY
-    REQUIREMENTS = ["evidently==v0.1.41.dev0"]
+    REQUIREMENTS = ["evidently==0.1.52dev0"]
+
+    @staticmethod
+    def activate() -> None:
+        """Activate the Deepchecks integration."""
+        from zenml.integrations.evidently import materializers  # noqa
+        from zenml.integrations.evidently import visualizers  # noqa
+
+    @classmethod
+    def flavors(cls) -> List[Type[Flavor]]:
+        """Declare the stack component flavors for the Great Expectations integration.
+
+        Returns:
+            List of stack component flavors for this integration.
+        """
+        from zenml.integrations.evidently.flavors import (
+            EvidentlyDataValidatorFlavor,
+        )
+
+        return [EvidentlyDataValidatorFlavor]
 
 
 EvidentlyIntegration.check_installation()
