@@ -14,6 +14,8 @@
 """Initialization of the Evidently Standard Steps."""
 
 from zenml.integrations.evidently.steps.evidently_profile import (
-    EvidentlyProfileConfig,
+    EvidentlyColumnMapping,
+    EvidentlyProfileParameters,
     EvidentlyProfileStep,
+    evidently_profile_step,
 )
