@@ -4,15 +4,16 @@
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at:
 #
-#       http://www.apache.org/licenses/LICENSE-2.0
+#       https://www.apache.org/licenses/LICENSE-2.0
 #
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 #  or implied. See the License for the specific language governing
 #  permissions and limitations under the License.
-"""
-The Facets integration provides a simple way to visualise post-execution objects
+"""Facets integration for ZenML.
+
+The Facets integration provides a simple way to visualize post-execution objects
 like `PipelineView`, `PipelineRunView` and `StepView`. These objects can be
 extended using the `BaseVisualization` class. This integration requires
 `facets-overview` be installed in your Python environment.
@@ -23,11 +24,10 @@ from zenml.integrations.integration import Integration
 
 
 class FacetsIntegration(Integration):
-    """Definition of [Facet](https://pair-code.github.io/facets/) integration
-    for ZenML."""
+    """Definition of [Facet](https://pair-code.github.io/facets/) integration for ZenML."""
 
     NAME = FACETS
-    REQUIREMENTS = ["facets-overview>=1.0.0"]
+    REQUIREMENTS = ["facets-overview>=1.0.0", "IPython"]
 
 
 FacetsIntegration.check_installation()
