@@ -14,8 +14,8 @@
 """Initialization of the GCP ZenML integration.
 
 The GCP integration submodule provides a way to run ZenML pipelines in a cloud
-environment. Specifically, it allows the use of cloud artifact stores, metadata
-stores, and an `io` module to handle file operations on Google Cloud Storage
+environment. Specifically, it allows the use of cloud artifact stores
+and provides an `io` module to handle file operations on Google Cloud Storage
 (GCS).
 
 Additionally, the GCP secrets manager integration submodule provides a
@@ -25,15 +25,14 @@ The Vertex AI integration submodule provides a way to run ZenML pipelines in a
 Vertex AI environment.
 """
 
-from typing import List
+from typing import List, Type
 
-from zenml.enums import StackComponentType
 from zenml.integrations.constants import GCP
 from zenml.integrations.integration import Integration
-from zenml.zen_stores.models import FlavorWrapper
+from zenml.stack import Flavor
 
 GCP_ARTIFACT_STORE_FLAVOR = "gcp"
-GCP_SECRETS_MANAGER_FLAVOR = "gcp_secrets_manager"
+GCP_SECRETS_MANAGER_FLAVOR = "gcp"
 GCP_VERTEX_ORCHESTRATOR_FLAVOR = "vertex"
 GCP_VERTEX_STEP_OPERATOR_FLAVOR = "vertex"
 
@@ -43,48 +42,33 @@ class GcpIntegration(Integration):
 
     NAME = GCP
     REQUIREMENTS = [
-        "kfp",
+        "kfp==1.8.13",
         "gcsfs",
         "google-cloud-secret-manager",
         "google-cloud-aiplatform>=1.11.0",
+        "google-cloud-scheduler>=2.7.3",
+        "google-cloud-functions>=1.8.3",
     ]
 
     @classmethod
-    def flavors(cls) -> List[FlavorWrapper]:
+    def flavors(cls) -> List[Type[Flavor]]:
         """Declare the stack component flavors for the GCP integration.
 
         Returns:
             List of stack component flavors for this integration.
         """
+        from zenml.integrations.gcp.flavors import (
+            GCPArtifactStoreFlavor,
+            GCPSecretsManagerFlavor,
+            VertexOrchestratorFlavor,
+            VertexStepOperatorFlavor,
+        )
+
         return [
-            FlavorWrapper(
-                name=GCP_ARTIFACT_STORE_FLAVOR,
-                source="zenml.integrations.gcp.artifact_stores"
-                ".GCPArtifactStore",
-                type=StackComponentType.ARTIFACT_STORE,
-                integration=cls.NAME,
-            ),
-            FlavorWrapper(
-                name=GCP_SECRETS_MANAGER_FLAVOR,
-                source="zenml.integrations.gcp.secrets_manager."
-                "GCPSecretsManager",
-                type=StackComponentType.SECRETS_MANAGER,
-                integration=cls.NAME,
-            ),
-            FlavorWrapper(
-                name=GCP_VERTEX_ORCHESTRATOR_FLAVOR,
-                source="zenml.integrations.gcp.orchestrators"
-                ".VertexOrchestrator",
-                type=StackComponentType.ORCHESTRATOR,
-                integration=cls.NAME,
-            ),
-            FlavorWrapper(
-                name=GCP_VERTEX_STEP_OPERATOR_FLAVOR,
-                source="zenml.integrations.gcp.step_operators"
-                ".VertexStepOperator",
-                type=StackComponentType.STEP_OPERATOR,
-                integration=cls.NAME,
-            ),
+            VertexOrchestratorFlavor,
+            VertexStepOperatorFlavor,
+            GCPSecretsManagerFlavor,
+            GCPArtifactStoreFlavor,
         ]
 
 
