@@ -16,12 +16,11 @@
 The MLflow integrations currently enables you to use MLflow tracking as a
 convenient way to visualize your experiment runs within the MLflow UI.
 """
-from typing import List
+from typing import List, Type
 
-from zenml.enums import StackComponentType
 from zenml.integrations.constants import MLFLOW
 from zenml.integrations.integration import Integration
-from zenml.zen_stores.models import FlavorWrapper
+from zenml.stack import Flavor
 
 MLFLOW_MODEL_DEPLOYER_FLAVOR = "mlflow"
 MLFLOW_MODEL_EXPERIMENT_TRACKER_FLAVOR = "mlflow"
@@ -31,10 +30,14 @@ class MlflowIntegration(Integration):
     """Definition of MLflow integration for ZenML."""
 
     NAME = MLFLOW
+    # We need to pin protobuf to a version <=4 here, as this mlflow release
+    # does not pin it. They fixed this in a later version, so we can probably
+    # remove this once we update the mlflow version.
     REQUIREMENTS = [
         "mlflow>=1.2.0,<1.26.0",
         "mlserver>=0.5.3",
         "mlserver-mlflow>=0.5.3",
+        "protobuf>=3.7.0,<4.0.0",
     ]
 
     @classmethod
@@ -43,26 +46,18 @@ class MlflowIntegration(Integration):
         from zenml.integrations.mlflow import services  # noqa
 
     @classmethod
-    def flavors(cls) -> List[FlavorWrapper]:
+    def flavors(cls) -> List[Type[Flavor]]:
         """Declare the stack component flavors for the MLflow integration.
 
         Returns:
             List of stack component flavors for this integration.
         """
-        return [
-            FlavorWrapper(
-                name=MLFLOW_MODEL_DEPLOYER_FLAVOR,
-                source="zenml.integrations.mlflow.model_deployers.MLFlowModelDeployer",
-                type=StackComponentType.MODEL_DEPLOYER,
-                integration=cls.NAME,
-            ),
-            FlavorWrapper(
-                name=MLFLOW_MODEL_EXPERIMENT_TRACKER_FLAVOR,
-                source="zenml.integrations.mlflow.experiment_trackers.MLFlowExperimentTracker",
-                type=StackComponentType.EXPERIMENT_TRACKER,
-                integration=cls.NAME,
-            ),
-        ]
+        from zenml.integrations.mlflow.flavors import (
+            MLFlowExperimentTrackerFlavor,
+            MLFlowModelDeployerFlavor,
+        )
+
+        return [MLFlowModelDeployerFlavor, MLFlowExperimentTrackerFlavor]
 
 
 MlflowIntegration.check_installation()
