@@ -22,7 +22,7 @@ class NeuralProphetIntegration(Integration):
     """Definition of NeuralProphet integration for ZenML."""
 
     NAME = NEURAL_PROPHET
-    REQUIREMENTS = ["neuralprophet>=0.3.2"]
+    REQUIREMENTS = ["neuralprophet>=0.3.2,<0.5.0"]
 
     @classmethod
     def activate(cls) -> None:
