@@ -15,20 +15,33 @@
 
 import re
 from datetime import datetime
-from typing import ClassVar, Dict, List, Optional, cast
+from typing import TYPE_CHECKING, ClassVar, Dict, List, Optional, Type, cast
 from uuid import UUID
 
-from zenml.integrations.seldon import SELDON_MODEL_DEPLOYER_FLAVOR
+from zenml.client import Client
+from zenml.integrations.seldon.constants import (
+    SELDON_CUSTOM_DEPLOYMENT,
+    SELDON_DOCKER_IMAGE_KEY,
+)
+from zenml.integrations.seldon.flavors.seldon_model_deployer_flavor import (
+    SeldonModelDeployerConfig,
+    SeldonModelDeployerFlavor,
+)
 from zenml.integrations.seldon.seldon_client import SeldonClient
 from zenml.integrations.seldon.services.seldon_deployment import (
     SeldonDeploymentConfig,
     SeldonDeploymentService,
 )
 from zenml.logger import get_logger
-from zenml.model_deployers.base_model_deployer import BaseModelDeployer
-from zenml.repository import Repository
+from zenml.model_deployers import BaseModelDeployer, BaseModelDeployerFlavor
 from zenml.secrets_managers import BaseSecretsManager
 from zenml.services.service import BaseService, ServiceConfig
+from zenml.stack.stack import Stack
+from zenml.utils.analytics_utils import AnalyticsEvent, event_handler
+from zenml.utils.pipeline_docker_image_builder import PipelineDockerImageBuilder
+
+if TYPE_CHECKING:
+    from zenml.config.pipeline_deployment import PipelineDeployment
 
 logger = get_logger(__name__)
 
@@ -36,40 +49,22 @@ DEFAULT_SELDON_DEPLOYMENT_START_STOP_TIMEOUT = 300
 
 
 class SeldonModelDeployer(BaseModelDeployer):
-    """Seldon Core model deployer stack component implementation.
+    """Seldon Core model deployer stack component implementation."""
 
-    Attributes:
-        kubernetes_context: the Kubernetes context to use to contact the remote
-            Seldon Core installation. If not specified, the current
-            configuration is used. Depending on where the Seldon model deployer
-            is being used, this can be either a locally active context or an
-            in-cluster Kubernetes configuration (if running inside a pod).
-        kubernetes_namespace: the Kubernetes namespace where the Seldon Core
-            deployment servers are provisioned and managed by ZenML. If not
-            specified, the namespace set in the current configuration is used.
-            Depending on where the Seldon model deployer is being used, this can
-            be either the current namespace configured in the locally active
-            context or the namespace in the context of which the pod is running
-            (if running inside a pod).
-        base_url: the base URL of the Kubernetes ingress used to expose the
-            Seldon Core deployment servers.
-        secret: the name of a ZenML secret containing the credentials used by
-            Seldon Core storage initializers to authenticate to the Artifact
-            Store (i.e. the storage backend where models are stored - see
-            https://docs.seldon.io/projects/seldon-core/en/latest/servers/overview.html#handling-credentials).
-    """
+    NAME: ClassVar[str] = "Seldon Core"
+    FLAVOR: ClassVar[Type[BaseModelDeployerFlavor]] = SeldonModelDeployerFlavor
 
-    # Class Configuration
-    FLAVOR: ClassVar[str] = SELDON_MODEL_DEPLOYER_FLAVOR
-
-    kubernetes_context: Optional[str]
-    kubernetes_namespace: Optional[str]
-    base_url: str
-    secret: Optional[str]
-
-    # private attributes
     _client: Optional[SeldonClient] = None
 
+    @property
+    def config(self) -> SeldonModelDeployerConfig:
+        """Returns the `SeldonModelDeployerConfig` config.
+
+        Returns:
+            The configuration.
+        """
+        return cast(SeldonModelDeployerConfig, self._config)
+
     @staticmethod
     def get_model_server_info(  # type: ignore[override]
         service_instance: "SeldonDeploymentService",
@@ -89,35 +84,6 @@ class SeldonModelDeployer(BaseModelDeployer):
             "SELDON_DEPLOYMENT": service_instance.seldon_deployment_name,
         }
 
-    @staticmethod
-    def get_active_model_deployer() -> "SeldonModelDeployer":
-        """Get the Seldon Core model deployer registered in the active stack.
-
-        Returns:
-            The Seldon Core model deployer registered in the active stack.
-
-        Raises:
-            TypeError: if the Seldon Core model deployer is not available.
-        """
-        model_deployer = Repository(  # type: ignore [call-arg]
-            skip_repository_check=True
-        ).active_stack.model_deployer
-        if not model_deployer or not isinstance(
-            model_deployer, SeldonModelDeployer
-        ):
-            raise TypeError(
-                f"The active stack needs to have a Seldon Core model deployer "
-                f"component registered to be able to deploy models with Seldon "
-                f"Core. You can create a new stack with a Seldon Core model "
-                f"deployer component or update your existing stack to add this "
-                f"component, e.g.:\n\n"
-                f"  'zenml model-deployer register seldon --flavor={SELDON_MODEL_DEPLOYER_FLAVOR} "
-                f"--kubernetes_context=context-name --kubernetes_namespace="
-                f"namespace-name --base_url=https://ingress.cluster.kubernetes'\n"
-                f"  'zenml stack create stack-name -d seldon ...'\n"
-            )
-        return model_deployer
-
     @property
     def seldon_client(self) -> SeldonClient:
         """Get the Seldon Core client associated with this model deployer.
@@ -127,8 +93,8 @@ class SeldonModelDeployer(BaseModelDeployer):
         """
         if not self._client:
             self._client = SeldonClient(
-                context=self.kubernetes_context,
-                namespace=self.kubernetes_namespace,
+                context=self.config.kubernetes_context,
+                namespace=self.config.kubernetes_namespace,
             )
         return self._client
 
@@ -145,14 +111,41 @@ class SeldonModelDeployer(BaseModelDeployer):
             The Seldon Core Kubernetes secret name, or None if no secret is
             configured.
         """
-        if not self.secret:
+        if not self.config.secret:
             return None
         return (
-            re.sub(r"[^0-9a-zA-Z-]+", "-", f"zenml-seldon-core-{self.secret}")
+            re.sub(
+                r"[^0-9a-zA-Z-]+",
+                "-",
+                f"zenml-seldon-core-{self.config.secret}",
+            )
             .strip("-")
             .lower()
         )
 
+    def prepare_pipeline_deployment(
+        self,
+        deployment: "PipelineDeployment",
+        stack: "Stack",
+    ) -> None:
+        """Build a Docker image and push it to the container registry.
+
+        Args:
+            deployment: The pipeline deployment configuration.
+            stack: The stack on which the pipeline will be deployed.
+        """
+        needs_docker_image = False
+        for step in deployment.steps.values():
+            if step.config.extra.get(SELDON_CUSTOM_DEPLOYMENT, False) is True:
+                needs_docker_image = True
+
+        if needs_docker_image:
+            docker_image_builder = PipelineDockerImageBuilder()
+            repo_digest = docker_image_builder.build_and_push_docker_image(
+                deployment=deployment, stack=stack
+            )
+            deployment.add_extra(SELDON_DOCKER_IMAGE_KEY, repo_digest)
+
     def _create_or_update_kubernetes_secret(self) -> Optional[str]:
         """Create or update a Kubernetes secret.
 
@@ -168,11 +161,9 @@ class SeldonModelDeployer(BaseModelDeployer):
         # if a ZenML secret was configured in the model deployer,
         # create a Kubernetes secret as a means to pass this information
         # to the Seldon Core deployment
-        if self.secret:
+        if self.config.secret:
 
-            secret_manager = Repository(  # type: ignore [call-arg]
-                skip_repository_check=True
-            ).active_stack.secrets_manager
+            secret_manager = Client().active_stack.secrets_manager
 
             if not secret_manager or not isinstance(
                 secret_manager, BaseSecretsManager
@@ -180,14 +171,14 @@ class SeldonModelDeployer(BaseModelDeployer):
                 raise RuntimeError(
                     f"The active stack doesn't have a secret manager component. "
                     f"The ZenML secret specified in the Seldon Core Model "
-                    f"Deployer configuration cannot be fetched: {self.secret}."
+                    f"Deployer configuration cannot be fetched: {self.config.secret}."
                 )
 
             try:
-                zenml_secret = secret_manager.get_secret(self.secret)
+                zenml_secret = secret_manager.get_secret(self.config.secret)
             except KeyError:
                 raise RuntimeError(
-                    f"The ZenML secret '{self.secret}' specified in the "
+                    f"The ZenML secret '{self.config.secret}' specified in the "
                     f"Seldon Core Model Deployer configuration was not found "
                     f"in the active stack's secret manager."
                 )
@@ -276,52 +267,70 @@ class SeldonModelDeployer(BaseModelDeployer):
                 to start, or if an operational failure is encountered before
                 it reaches a ready state.
         """
-        config = cast(SeldonDeploymentConfig, config)
-        service = None
+        with event_handler(AnalyticsEvent.MODEL_DEPLOYED) as analytics_handler:
+            config = cast(SeldonDeploymentConfig, config)
+            service = None
 
-        # if a custom Kubernetes secret is not explicitly specified in the
-        # SeldonDeploymentConfig, try to create one from the ZenML secret
-        # configured for the model deployer
-        config.secret_name = (
-            config.secret_name or self._create_or_update_kubernetes_secret()
-        )
-
-        # if replace is True, find equivalent Seldon Core deployments
-        if replace is True:
-            equivalent_services = self.find_model_server(
-                running=False,
-                pipeline_name=config.pipeline_name,
-                pipeline_step_name=config.pipeline_step_name,
-                model_name=config.model_name,
+            # if a custom Kubernetes secret is not explicitly specified in the
+            # SeldonDeploymentConfig, try to create one from the ZenML secret
+            # configured for the model deployer
+            config.secret_name = (
+                config.secret_name or self._create_or_update_kubernetes_secret()
             )
 
-            for equivalent_service in equivalent_services:
-                if service is None:
-                    # keep the most recently created service
-                    service = equivalent_service
-                else:
-                    try:
-                        # delete the older services and don't wait for them to
-                        # be deprovisioned
-                        service.stop()
-                    except RuntimeError:
-                        # ignore errors encountered while stopping old services
-                        pass
+            # if replace is True, find equivalent Seldon Core deployments
+            if replace is True:
+                equivalent_services = self.find_model_server(
+                    running=False,
+                    pipeline_name=config.pipeline_name,
+                    pipeline_step_name=config.pipeline_step_name,
+                    model_name=config.model_name,
+                )
 
-        if service:
-            # update an equivalent service in place
-            service.update(config)
-            logger.info(
-                f"Updating an existing Seldon deployment service: {service}"
-            )
-        else:
-            # create a new service
-            service = SeldonDeploymentService(config=config)
-            logger.info(f"Creating a new Seldon deployment service: {service}")
+                for equivalent_service in equivalent_services:
+                    if service is None:
+                        # keep the most recently created service
+                        service = equivalent_service
+                    else:
+                        try:
+                            # delete the older services and don't wait for
+                            # them to be deprovisioned
+                            service.stop()
+                        except RuntimeError:
+                            # ignore errors encountered while stopping old
+                            # services
+                            pass
+
+            if service:
+                # update an equivalent service in place
+                service.update(config)
+                logger.info(
+                    f"Updating an existing Seldon deployment service: {service}"
+                )
+            else:
+                # create a new service
+                service = SeldonDeploymentService(config=config)
+                logger.info(
+                    f"Creating a new Seldon deployment service: {service}"
+                )
+
+            # start the service which in turn provisions the Seldon Core
+            # deployment server and waits for it to reach a ready state
+            service.start(timeout=timeout)
+
+            # Add telemetry with metadata that gets the stack metadata and
+            # differentiates between pure model and custom code deployments
+            stack = Client().active_stack
+            stack_metadata = {
+                component_type.value: component.flavor
+                for component_type, component in stack.components.items()
+            }
+            analytics_handler.metadata = {
+                "store_type": Client().zen_store.type.value,
+                **stack_metadata,
+                "is_custom_code_deployment": config.is_custom_deployment,
+            }
 
-        # start the service which in turn provisions the Seldon Core
-        # deployment server and waits for it to reach a ready state
-        service.start(timeout=timeout)
         return service
 
     def find_model_server(
@@ -343,8 +352,8 @@ class SeldonModelDeployer(BaseModelDeployer):
 
         Args:
             running: if true, only running services will be returned.
-            service_uuid: the UUID of the Seldon Core service that was originally used
-                to create the Seldon Core deployment resource.
+            service_uuid: the UUID of the Seldon Core service that was
+                originally used to create the Seldon Core deployment resource.
             pipeline_name: name of the pipeline that the deployed model was part
                 of.
             pipeline_run_id: ID of the pipeline run which the deployed model was
