@@ -13,11 +13,11 @@
 #  permissions and limitations under the License.
 """Implementation for the Seldon Deployment step."""
 
+import json
 import os
-from typing import TYPE_CHECKING, Any, Dict, Generator, Optional, Tuple
+from typing import Any, Dict, Generator, Optional, Tuple, cast
 from uuid import UUID
 
-import numpy as np
 import requests
 from pydantic import Field, ValidationError
 
@@ -32,9 +32,6 @@ from zenml.services.service import BaseService, ServiceConfig
 from zenml.services.service_status import ServiceState, ServiceStatus
 from zenml.services.service_type import ServiceType
 
-if TYPE_CHECKING:
-    from numpy.typing import NDArray
-
 logger = get_logger(__name__)
 
 
@@ -46,6 +43,8 @@ class SeldonDeploymentConfig(ServiceConfig):
         model_name: the name of the model. Multiple versions of the same model
             should use the same model name.
         implementation: the Seldon Core implementation used to serve the model.
+            The implementation type can be one of the following: `TENSORFLOW_SERVER`,
+            `SKLEARN_SERVER`, `XGBOOST_SERVER`, `custom`.
         replicas: number of replicas to use for the prediction service.
         secret_name: the name of a Kubernetes secret containing additional
             configuration parameters for the Seldon Core deployment (e.g.
@@ -54,6 +53,8 @@ class SeldonDeploymentConfig(ServiceConfig):
             https://docs.seldon.io/projects/seldon-core/en/latest/reference/apis/metadata.html).
         extra_args: additional arguments to pass to the Seldon Core deployment
             resource configuration.
+        is_custom_deployment: whether the deployment is a custom deployment
+        spec: custom Kubernetes resource specification for the Seldon Core
     """
 
     model_uri: str = ""
@@ -64,6 +65,8 @@ class SeldonDeploymentConfig(ServiceConfig):
     secret_name: Optional[str]
     model_metadata: Dict[str, Any] = Field(default_factory=dict)
     extra_args: Dict[str, Any] = Field(default_factory=dict)
+    is_custom_deployment: Optional[bool] = False
+    spec: Optional[Dict[Any, Any]] = Field(default_factory=dict)
 
     def get_seldon_deployment_labels(self) -> Dict[str, str]:
         """Generate labels for the Seldon Core deployment from the service configuration.
@@ -181,7 +184,9 @@ class SeldonDeploymentService(BaseService):
             SeldonModelDeployer,
         )
 
-        model_deployer = SeldonModelDeployer.get_active_model_deployer()
+        model_deployer = cast(
+            SeldonModelDeployer, SeldonModelDeployer.get_active_model_deployer()
+        )
         return model_deployer.seldon_client
 
     def check_status(self) -> Tuple[ServiceState, str]:
@@ -287,6 +292,8 @@ class SeldonDeploymentService(BaseService):
             secret_name=self.config.secret_name,
             labels=self._get_seldon_deployment_labels(),
             annotations=self.config.get_seldon_deployment_annotations(),
+            is_custom_deployment=self.config.is_custom_deployment,
+            spec=self.config.spec,
         )
         deployment.spec.replicas = self.config.replicas
         deployment.spec.predictors[0].replicas = self.config.replicas
@@ -349,16 +356,18 @@ class SeldonDeploymentService(BaseService):
         if not self.is_running:
             return None
         namespace = self._get_client().namespace
-        model_deployer = SeldonModelDeployer.get_active_model_deployer()
+        model_deployer = cast(
+            SeldonModelDeployer, SeldonModelDeployer.get_active_model_deployer()
+        )
         return os.path.join(
-            model_deployer.base_url,
+            model_deployer.config.base_url,
             "seldon",
             namespace,
             self.seldon_deployment_name,
             "api/v0.1/predictions",
         )
 
-    def predict(self, request: "NDArray[Any]") -> "NDArray[Any]":
+    def predict(self, request: str) -> Any:
         """Make a prediction using the service.
 
         Args:
@@ -379,9 +388,14 @@ class SeldonDeploymentService(BaseService):
 
         if self.prediction_url is None:
             raise ValueError("`self.prediction_url` is not set, cannot post.")
+
+        if isinstance(request, str):
+            request = json.loads(request)
+        else:
+            raise ValueError("Request must be a json string.")
         response = requests.post(
             self.prediction_url,
-            json={"data": {"ndarray": request.tolist()}},
+            json={"data": {"ndarray": request}},
         )
         response.raise_for_status()
-        return np.array(response.json()["data"]["ndarray"])
+        return response.json()
