@@ -4,13 +4,14 @@
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at:
 #
-#       http://www.apache.org/licenses/LICENSE-2.0
+#       https://www.apache.org/licenses/LICENSE-2.0
 #
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 #  or implied. See the License for the specific language governing
 #  permissions and limitations under the License.
+"""Implementation of the sklearn materializer."""
 
 import os
 import pickle
@@ -29,6 +30,8 @@ from sklearn.base import (
     TransformerMixin,
 )
 
+from zenml.artifacts import ModelArtifact
+from zenml.io import fileio
 from zenml.materializers.base_materializer import BaseMaterializer
 
 DEFAULT_FILENAME = "model"
@@ -37,7 +40,7 @@ DEFAULT_FILENAME = "model"
 class SklearnMaterializer(BaseMaterializer):
     """Materializer to read data to and from sklearn."""
 
-    ASSOCIATED_TYPES = [
+    ASSOCIATED_TYPES = (
         BaseEstimator,
         ClassifierMixin,
         ClusterMixin,
@@ -48,7 +51,8 @@ class SklearnMaterializer(BaseMaterializer):
         MultiOutputMixin,
         DensityMixin,
         TransformerMixin,
-    ]
+    )
+    ASSOCIATED_ARTIFACT_TYPES = (ModelArtifact,)
 
     def handle_input(
         self, data_type: Type[Any]
@@ -64,10 +68,17 @@ class SklearnMaterializer(BaseMaterializer):
         DensityMixin,
         TransformerMixin,
     ]:
-        """Reads a base sklearn model from a pickle file."""
+        """Reads a base sklearn model from a pickle file.
+
+        Args:
+            data_type: The type of the model.
+
+        Returns:
+            The model.
+        """
         super().handle_input(data_type)
         filepath = os.path.join(self.artifact.uri, DEFAULT_FILENAME)
-        with open(filepath, "rb") as fid:
+        with fileio.open(filepath, "rb") as fid:
             clf = pickle.load(fid)
         return clf
 
@@ -93,5 +104,5 @@ class SklearnMaterializer(BaseMaterializer):
         """
         super().handle_return(clf)
         filepath = os.path.join(self.artifact.uri, DEFAULT_FILENAME)
-        with open(filepath, "wb") as fid:
+        with fileio.open(filepath, "wb") as fid:
             pickle.dump(clf, fid)
