@@ -22,7 +22,26 @@ ZenML supports a local orchestrator out of the box which allows you to run your
 pipelines in a local environment. We also support using Apache Airflow as the
 orchestrator to handle the steps of your pipeline.
 """
-from zenml.orchestrators.base_orchestrator import BaseOrchestrator
-from zenml.orchestrators.local.local_orchestrator import LocalOrchestrator
+from zenml.orchestrators.base_orchestrator import (
+    BaseOrchestrator,
+    BaseOrchestratorConfig,
+    BaseOrchestratorFlavor,
+)
+from zenml.orchestrators.local.local_orchestrator import (
+    LocalOrchestrator,
+    LocalOrchestratorFlavor,
+)
+from zenml.orchestrators.local_docker.local_docker_orchestrator import (
+    LocalDockerOrchestrator,
+    LocalDockerOrchestratorFlavor,
+)
 
-__all__ = ["BaseOrchestrator", "LocalOrchestrator"]
+__all__ = [
+    "BaseOrchestrator",
+    "BaseOrchestratorConfig",
+    "BaseOrchestratorFlavor",
+    "LocalOrchestrator",
+    "LocalOrchestratorFlavor",
+    "LocalDockerOrchestrator",
+    "LocalDockerOrchestratorFlavor",
+]
