@@ -14,14 +14,15 @@
 """Initialization for the post-execution artifact class."""
 
 from typing import TYPE_CHECKING, Any, Optional, Type
+from uuid import UUID
 
 from zenml.logger import get_logger
 from zenml.utils import source_utils
 
 if TYPE_CHECKING:
     from zenml.materializers.base_materializer import BaseMaterializer
-    from zenml.metadata_stores import BaseMetadataStore
-    from zenml.post_execution.step import StepView
+    from zenml.models import ArtifactResponseModel
+
 
 logger = get_logger(__name__)
 
@@ -33,50 +34,34 @@ class ArtifactView:
     execution.
     """
 
-    def __init__(
-        self,
-        id_: int,
-        type_: str,
-        uri: str,
-        materializer: str,
-        data_type: str,
-        metadata_store: "BaseMetadataStore",
-        parent_step_id: int,
-    ):
+    def __init__(self, model: "ArtifactResponseModel"):
         """Initializes a post-execution artifact object.
 
         In most cases `ArtifactView` objects should not be created manually but
         retrieved from a `StepView` via the `inputs` or `outputs` properties.
 
         Args:
-            id_: The artifact id.
-            type_: The type of this artifact.
-            uri: Specifies where the artifact data is stored.
-            materializer: Information needed to restore the materializer
-                that was used to write this artifact.
-            data_type: The type of data that was passed to the materializer
-                when writing that artifact. Will be used as a default type
-                to read the artifact.
-            metadata_store: The metadata store which should be used to fetch
-                additional information related to this pipeline.
-            parent_step_id: The ID of the parent step.
+            model: The model to initialize this object from.
         """
-        self._id = id_
-        self._type = type_
-        self._uri = uri
-        self._materializer = materializer
-        self._data_type = data_type
-        self._metadata_store = metadata_store
-        self._parent_step_id = parent_step_id
+        self._model = model
 
     @property
-    def id(self) -> int:
+    def id(self) -> UUID:
         """Returns the artifact id.
 
         Returns:
             The artifact id.
         """
-        return self._id
+        return self._model.id
+
+    @property
+    def name(self) -> str:
+        """Returns the name of the artifact (output name in the parent step).
+
+        Returns:
+            The name of the artifact.
+        """
+        return self._model.name
 
     @property
     def type(self) -> str:
@@ -85,7 +70,7 @@ class ArtifactView:
         Returns:
             The artifact type.
         """
-        return self._type
+        return self._model.type
 
     @property
     def data_type(self) -> str:
@@ -94,7 +79,7 @@ class ArtifactView:
         Returns:
             The data type of the artifact.
         """
-        return self._data_type
+        return self._model.data_type
 
     @property
     def uri(self) -> str:
@@ -103,39 +88,25 @@ class ArtifactView:
         Returns:
             The URI where the artifact data is stored.
         """
-        return self._uri
+        return self._model.uri
 
     @property
-    def parent_step_id(self) -> int:
-        """Returns the ID of the parent step.
-
-        This need not be equivalent to the ID of the producer step.
+    def materializer(self) -> str:
+        """Returns the materializer that was used to write this artifact.
 
         Returns:
-            The ID of the parent step.
+            The materializer that was used to write this artifact.
         """
-        return self._parent_step_id
+        return self._model.materializer
 
     @property
-    def producer_step(self) -> "StepView":
-        """Returns the original StepView that produced the artifact.
+    def producer_step_id(self) -> Optional[UUID]:
+        """Returns the ID of the original step that produced the artifact.
 
         Returns:
-            The original StepView that produced the artifact.
+            The ID of the original step that produced the artifact.
         """
-        # TODO [ENG-174]: Replace with artifact.id instead of passing self if
-        #  required.
-        return self._metadata_store.get_producer_step_from_artifact(self)
-
-    @property
-    def is_cached(self) -> bool:
-        """Returns True if artifact was cached in a previous run, else False.
-
-        Returns:
-            True if artifact was cached in a previous run, else False.
-        """
-        # self._metadata_store.
-        return self.producer_step.id != self.parent_step_id
+        return self._model.producer_step_run_id
 
     def read(
         self,
@@ -161,12 +132,12 @@ class ArtifactView:
         if not materializer_class:
             try:
                 materializer_class = source_utils.load_source_path_class(
-                    self._materializer
+                    self.materializer
                 )
             except (ModuleNotFoundError, AttributeError) as e:
                 logger.error(
                     f"ZenML can not locate and import the materializer module "
-                    f"{self._materializer} which was used to write this "
+                    f"{self.materializer} which was used to write this "
                     f"artifact. If you want to read from it, please provide "
                     f"a 'materializer_class'."
                 )
@@ -175,12 +146,12 @@ class ArtifactView:
         if not output_data_type:
             try:
                 output_data_type = source_utils.load_source_path_class(
-                    self._data_type
+                    self.data_type
                 )
             except (ModuleNotFoundError, AttributeError) as e:
                 logger.error(
                     f"ZenML can not locate and import the data type of this "
-                    f"artifact {self._data_type}. If you want to read "
+                    f"artifact {self.data_type}. If you want to read "
                     f"from it, please provide a 'output_data_type'."
                 )
                 raise ModuleNotFoundError(e) from e
@@ -188,8 +159,8 @@ class ArtifactView:
         logger.debug(
             "Using '%s' to read '%s' (uri: %s).",
             materializer_class.__qualname__,
-            self._type,
-            self._uri,
+            self.type,
+            self.uri,
         )
 
         # TODO [ENG-162]: passing in `self` to initialize the materializer only
@@ -205,9 +176,9 @@ class ArtifactView:
             A string representation of this artifact.
         """
         return (
-            f"{self.__class__.__qualname__}(id={self._id}, "
-            f"type='{self._type}', uri='{self._uri}', "
-            f"materializer='{self._materializer}')"
+            f"{self.__class__.__qualname__}(id={self.id}, "
+            f"type='{self.type}', uri='{self.uri}', "
+            f"materializer='{self.materializer}')"
         )
 
     def __eq__(self, other: Any) -> bool:
@@ -221,5 +192,5 @@ class ArtifactView:
             False.
         """
         if isinstance(other, ArtifactView):
-            return self._id == other._id and self._uri == other._uri
+            return self.id == other.id and self.uri == other.uri
         return NotImplemented
