@@ -17,10 +17,9 @@ from typing import Any, ClassVar, Dict
 
 from pydantic import root_validator
 
+from zenml.constants import ARBITRARY_SECRET_SCHEMA_TYPE
 from zenml.secret.base_secret import BaseSecretSchema
 
-ARBITRARY_SECRET_SCHEMA_TYPE = "arbitrary"
-
 
 class ArbitrarySecretSchema(BaseSecretSchema):
     """Schema for arbitrary collections of key value pairs with no predefined schema."""
