@@ -55,11 +55,16 @@ class LocalDaemonServiceConfig(ServiceConfig):
             directly in the `root_runtime_path` directory instead of creating
             a subdirectory for each service instance. Only has effect if the
             `root_runtime_path` is also set.
+        blocking: set to True to run the service the context of the current
+            process and block until the service is stopped instead of running
+            the service as a daemon process. Useful for operating systems
+            that do not support daemon processes.
     """
 
     silent_daemon: bool = False
     root_runtime_path: Optional[str] = None
     singleton: bool = False
+    blocking: bool = False
 
 
 class LocalDaemonServiceStatus(ServiceStatus):
@@ -137,8 +142,16 @@ class LocalDaemonServiceStatus(ServiceStatus):
             import zenml.services.local.local_daemon_entrypoint as daemon_entrypoint
             from zenml.utils.daemon import get_daemon_pid_if_running
 
+            logger.debug(f"Checking PID file {pid_file}.")
+
             pid = get_daemon_pid_if_running(pid_file)
 
+            if not pid:
+                logger.debug(
+                    f"Process with PID file {pid_file} is no longer running."
+                )
+                return None
+
             # let's be extra careful here and check that the PID really
             # belongs to a process that is a local ZenML daemon.
             # this avoids the situation where a PID file is left over from
@@ -151,6 +164,10 @@ class LocalDaemonServiceStatus(ServiceStatus):
                     daemon_entrypoint.__name__ not in cmd_line
                     or self.config_file not in cmd_line
                 ):
+                    logger.debug(
+                        f"Process with PID {pid} is not a ZenML local daemon "
+                        f"service."
+                    )
                     return None
                 return pid
             except NoSuchProcess:
@@ -403,6 +420,19 @@ class LocalDaemonService(BaseService):
         """
         self._stop_daemon(force)
 
+    def start(self, timeout: int = 0) -> None:
+        """Start the service and optionally wait for it to become active.
+
+        Args:
+            timeout: amount of time to wait for the service to become active.
+                If set to 0, the method will return immediately after checking
+                the service status.
+        """
+        if not self.config.blocking:
+            super().start(timeout)
+        else:
+            self.run()
+
     def get_logs(
         self, follow: bool = False, tail: Optional[int] = None
     ) -> Generator[str, bool, None]:
