@@ -18,6 +18,7 @@ from typing import (
     Any,
     Callable,
     Dict,
+    Mapping,
     Optional,
     Type,
     TypeVar,
@@ -28,15 +29,31 @@ from typing import (
 from zenml.steps import BaseStep
 from zenml.steps.utils import (
     INSTANCE_CONFIGURATION,
-    OUTPUT_SPEC,
     PARAM_CREATED_BY_FUNCTIONAL_API,
-    PARAM_CUSTOM_STEP_OPERATOR,
     PARAM_ENABLE_CACHE,
+    PARAM_EXPERIMENT_TRACKER,
+    PARAM_EXTRA_OPTIONS,
+    PARAM_OUTPUT_ARTIFACTS,
+    PARAM_OUTPUT_MATERIALIZERS,
+    PARAM_SETTINGS,
+    PARAM_STEP_NAME,
+    PARAM_STEP_OPERATOR,
     STEP_INNER_FUNC_NAME,
 )
 
 if TYPE_CHECKING:
     from zenml.artifacts.base_artifact import BaseArtifact
+    from zenml.config.base_settings import SettingsOrDict
+    from zenml.materializers.base_materializer import BaseMaterializer
+
+    ArtifactClassOrStr = Union[str, Type["BaseArtifact"]]
+    MaterializerClassOrStr = Union[str, Type["BaseMaterializer"]]
+    OutputArtifactsSpecification = Union[
+        "ArtifactClassOrStr", Mapping[str, "ArtifactClassOrStr"]
+    ]
+    OutputMaterializersSpecification = Union[
+        "MaterializerClassOrStr", Mapping[str, "MaterializerClassOrStr"]
+    ]
 
 F = TypeVar("F", bound=Callable[..., Any])
 
@@ -51,8 +68,12 @@ def step(
     *,
     name: Optional[str] = None,
     enable_cache: bool = True,
-    output_types: Optional[Dict[str, Type["BaseArtifact"]]] = None,
-    custom_step_operator: Optional[str] = None,
+    experiment_tracker: Optional[str] = None,
+    step_operator: Optional[str] = None,
+    output_artifacts: Optional["OutputArtifactsSpecification"] = None,
+    output_materializers: Optional["OutputMaterializersSpecification"] = None,
+    settings: Optional[Dict[str, "SettingsOrDict"]] = None,
+    extra: Optional[Dict[str, Any]] = None,
 ) -> Callable[[F], Type[BaseStep]]:
     ...
 
@@ -62,8 +83,12 @@ def step(
     *,
     name: Optional[str] = None,
     enable_cache: Optional[bool] = None,
-    output_types: Optional[Dict[str, Type["BaseArtifact"]]] = None,
-    custom_step_operator: Optional[str] = None,
+    experiment_tracker: Optional[str] = None,
+    step_operator: Optional[str] = None,
+    output_artifacts: Optional["OutputArtifactsSpecification"] = None,
+    output_materializers: Optional["OutputMaterializersSpecification"] = None,
+    settings: Optional[Dict[str, "SettingsOrDict"]] = None,
+    extra: Optional[Dict[str, Any]] = None,
 ) -> Union[Type[BaseStep], Callable[[F], Type[BaseStep]]]:
     """Outer decorator function for the creation of a ZenML step.
 
@@ -77,11 +102,19 @@ def step(
         enable_cache: Specify whether caching is enabled for this step. If no
             value is passed, caching is enabled by default unless the step
             requires a `StepContext` (see
-            :class:`zenml.steps.step_context.StepContext` for more information).
-        output_types: A dictionary which sets different outputs to non-default
-            artifact types
-        custom_step_operator: Optional name of a
-            `zenml.step_operators.BaseStepOperator` to use for this step.
+            `zenml.steps.step_context.StepContext` for more information).
+        experiment_tracker: The experiment tracker to use for this step.
+        step_operator: The step operator to use for this step.
+        output_materializers: Output materializers for this step. If
+            given as a dict, the keys must be a subset of the output names
+            of this step. If a single value (type or string) is given, the
+            materializer will be used for all outputs.
+        output_artifacts: Output artifacts for this step. If
+            given as a dict, the keys must be a subset of the output names
+            of this step. If a single value (type or string) is given, the
+            artifact class will be used for all outputs.
+        settings: Settings for this step.
+        extra: Extra configurations for this step.
 
     Returns:
         the inner decorator which creates the step class based on the
@@ -98,20 +131,22 @@ def step(
         Returns:
             The class of a newly generated ZenML Step.
         """
-        step_name = name or func.__name__
-        output_spec = output_types or {}
-
         return type(  # noqa
-            step_name,
+            func.__name__,
             (BaseStep,),
             {
                 STEP_INNER_FUNC_NAME: staticmethod(func),
                 INSTANCE_CONFIGURATION: {
-                    PARAM_ENABLE_CACHE: enable_cache,
+                    PARAM_STEP_NAME: name,
                     PARAM_CREATED_BY_FUNCTIONAL_API: True,
-                    PARAM_CUSTOM_STEP_OPERATOR: custom_step_operator,
+                    PARAM_ENABLE_CACHE: enable_cache,
+                    PARAM_EXPERIMENT_TRACKER: experiment_tracker,
+                    PARAM_STEP_OPERATOR: step_operator,
+                    PARAM_OUTPUT_ARTIFACTS: output_artifacts,
+                    PARAM_OUTPUT_MATERIALIZERS: output_materializers,
+                    PARAM_SETTINGS: settings,
+                    PARAM_EXTRA_OPTIONS: extra,
                 },
-                OUTPUT_SPEC: output_spec,
                 "__module__": func.__module__,
                 "__doc__": func.__doc__,
             },
